@@ -14,15 +14,12 @@ class Signatures:
 
     def get_signature(self, buffer, file_version: int = -1) -> int:
         signature = Signatures.NONE
-        if self.last_signature == Signatures.SC and file_version == 1:
-            signature = Signatures.LZMA
-            self.last_signature = -1
-        elif buffer[:4] == b'\x28\xb5\x2f\xfd':  # self.last_signature == Signatures.SC and file_version >= 2:
-            signature = Signatures.ZSTD
-            self.last_signature = -1
 
         if re.match(b'\x00\x00?\x00', buffer[1:5]):
             signature = Signatures.LZMA
+        elif file_version >= 2 and buffer.startswith(b'\x28\xb5\x2f\xfd'):
+            signature = Signatures.ZSTD
+
         if buffer.startswith(b'SCLZ'):
             signature = Signatures.SCLZ
         elif buffer.startswith(b'SC'):
